/**
 *   _____ _       __          __            
 *  / ____(_)      \ \        / /            
 * | (___  _ _ __ __\ \  /\  / /_ _ _ __ ___ 
 *  \___ \| | '_ ` _ \ \/  \/ / _` | '__/ _ \
 *  ____) | | | | | | \  /\  / (_| | | |  __/
 * |_____/|_|_| |_| |_|\/  \/ \__,_|_|  \___|
 * 
 * This file is part of EasterHunt.
 * 
 * EasterHunt is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * EasterHunt is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with EasterHunt. If not, see <http://www.gnu.org/licenses/>.
 */
package com.simware.easterhunt;

import java.util.Random;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Paint.Align;
import android.graphics.Paint.Style;
import android.graphics.Point;
import android.graphics.PointF;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Typeface;
import android.util.AttributeSet;
import android.util.Log;
import android.view.MotionEvent;
import android.view.SurfaceHolder;
import android.view.SurfaceView;
import android.view.WindowManager;

import com.simware.util.DrawThread;
import com.simware.util.ImageUtils;

/**
 * Main class of the game, the magically none structural game class. Sorry for this, could
 * have been made nicer but this game was written for J2ME and needed to be tight.
 * 
 * <OL>
 *  <LI> 0 Grass.
 *  <LI> 1 Tree, Light Green.
 *  <LI> 2 Bush, thick.
 *  <LI> 3 Snow.
 *  <LI> 4 Tree, Furry.
 *  <LI> 5 Bush, light green small.
 *  <LI> 6 Treem Dark Green.
 *  <LI> 7 Bush, Tree lite.
 *  <LI> 8 Egg, Golden.
 *  <LI> 9 Egg, Brown.
 *  <LI> 10 Egg, Pink.
 *  <LI> 11 Egg, Red.
 *  <LI> Tree Kill 1, Thick.
 *  <LI> Tree Kill 2, Thick.
 *  <LI> Tree Kill 3, Tick.
 *  <LI> Tree Kill 4, Tick.
 *  <LI> Tree Kill 1, lite.
 *  <LI> Tree Kill 2, lite.
 *  <LI> Tree Kill 3, lite.
 *  <LI> Tree Kill 4, lite.
 * <OL>
 * @author simon.ohlmer@gmail.com
 */
public class EasterHuntGameEngine extends SurfaceView implements SurfaceHolder.Callback {

	private final static String TAG = EasterHuntGameEngine.class.getSimpleName();
	
    /** Number of eggs on this level **/
    private int m_numberOfEggs;

    /** The current score **/
    protected static EasterHuntScore m_score;

    /** The current number of enemies **/
    private int m_numberOfEnemies;

    /** The enemy array **/
    private EasterHuntFox m_emenies[];

    /** The current level **/
    private int m_level;

    /** The key press **/
    private int m_keyPress;

    /** The current state **/
    private int m_state;

    /** The bunny **/
    public EasterHuntBunny m_bunny;

    /** The current map, that we can change. **/
    protected EasterHuntMap m_currentMap;

    /** Random position of the enemey **/
    private static final Random randomObj = new Random();

    /** The Activity Context **/
    private static Context m_context = null;
    
    /** The current text on the screen **/
    private String m_message = null;
    
    /** 5 second message to notify the number of eggs remaining **/
    private String m_eggMessage = null; 
    
    /** The screen max size **/
    private Point m_maxScreenSize = new Point();
    
    /** Volume bitmap **/
    private Bitmap m_volume = null;
    private Bitmap m_muted = null;    
    
    private int m_level_1_map[][] = { 
    		{0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0}, 
    		{7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0}, 
    		{0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0}, 
    		{0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0}, 
            {0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0}, 
            {0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0}, 
            {0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0}, 
            {0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0}, 
            {0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3, 0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3, 0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3}, 
            {0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3},
            {0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0}, 
            {0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0, 0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0, 0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0}, 
            {0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 
            {0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7, 0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7, 0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7}, 
            {0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0, 0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0, 0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0},
            {0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11, 0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11, 0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11}, 
            {0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0, 0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0, 0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0}, 
            {0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10},
            {0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0}, 
    		{7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0}, 
    		{0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0}, 
    		{0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0}, 
            {0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0}, 
            {0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0}, 
            {0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0}, 
            {0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0}, 
            {0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3, 0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3, 0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3}, 
            {0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3},
            {0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0}, 
            {0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0, 0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0, 0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0}, 
            {0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 
            {0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7, 0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7, 0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7}, 
            {0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0, 0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0, 0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0},
            {0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11, 0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11, 0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11}, 
            {0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0, 0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0, 0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0}, 
            {0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10},
            {0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0}, 
    		{7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0}, 
    		{0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0}, 
    		{0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0}, 
            {0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0}, 
            {0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0}, 
            {0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0}, 
            {0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0}, 
            {0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3, 0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3, 0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3}, 
            {0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3},
            {0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0}, 
            {0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0, 0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0, 0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0}, 
            {0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 
            {0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7, 0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7, 0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7}, 
            {0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0, 0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0, 0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0},
            {0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11, 0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11, 0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11}, 
            {0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0, 0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0, 0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0}, 
            {0, 0,  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,  0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0,  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10},
            {0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10},
            {0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0}, 
    		{7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0}, 
    		{0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0}, 
    		{0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0}, 
            {0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0}, 
            {0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0}, 
            {0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0}, 
            {0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0}, 
            {0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3, 0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3, 0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3}, 
            {0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3},
            {0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0}, 
            {0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0, 0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0, 0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0}, 
            {0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 
            {0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7, 0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7, 0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7}, 
            {0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0, 0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0, 0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0},
            {0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11, 0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11, 0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11}, 
            {0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0, 0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0, 0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10},
            {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10} };
    
    //  4 times bigger
    private int m_level_2_map[][] = { 
    		{0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0,0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0 }, 
    		{7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0}, 
    		{0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0}, 
    		{0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0}, 
            {0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0}, 
            {0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0}, 
            {0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0}, 
            {0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0}, 
            {0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3, 0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3, 0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3, 0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3}, 
            {0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3},
            {0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0}, 
            {0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0, 0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0, 0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0, 0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0}, 
            {0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 
            {0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7, 0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7, 0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7, 0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7}, 
            {0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0, 0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0, 0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0, 0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0},
            {0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11, 0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11, 0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11, 0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11}, 
            {0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0, 0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0, 0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0, 0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0}, 
            {0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10},
    		{0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0,0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0 }, 
    		{7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0}, 
    		{0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0}, 
    		{0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0}, 
            {0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0}, 
            {0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0}, 
            {0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0}, 
            {0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0}, 
            {0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3, 0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3, 0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3, 0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3}, 
            {0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3},
            {0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0}, 
            {0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0, 0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0, 0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0, 0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0}, 
            {0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 
            {0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7, 0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7, 0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7, 0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7}, 
            {0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0, 0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0, 0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0, 0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0},
            {0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11, 0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11, 0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11, 0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11}, 
            {0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0, 0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0, 0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0, 0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0}, 
            {0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10},
    		{0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0,0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0 }, 
    		{7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0}, 
    		{0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0}, 
    		{0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0}, 
            {0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0}, 
            {0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0}, 
            {0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0}, 
            {0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0}, 
            {0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3, 0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3, 0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3, 0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3}, 
            {0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3},
            {0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0}, 
            {0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0, 0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0, 0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0, 0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0}, 
            {0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 
            {0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7, 0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7, 0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7, 0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7}, 
            {0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0, 0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0, 0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0, 0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0},
            {0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11, 0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11, 0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11, 0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11}, 
            {0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0, 0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0, 0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0, 0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0}, 
            {0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10},
    		{0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0,0, 7, 0, 0, 0, 0, 8, 0, 0, 5, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0 }, 
    		{7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 7, 7, 0, 0, 0, 0, 0, 0, 6, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 6, 0, 0}, 
    		{0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 1, 0, 3, 0, 0, 0, 11, 1, 0, 0, 0}, 
    		{0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 3, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0}, 
            {0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 3, 0, 3, 3, 0, 0, 0, 0, 3, 0, 0, 0}, 
            {0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 3, 0, 3, 0, 0, 10, 0, 3, 3, 3, 0, 0}, 
            {0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 7, 6, 0, 3, 3, 0, 3, 0, 0}, 
            {0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 5, 2, 0, 3, 0, 0, 3, 3, 0}, 
            {0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3, 0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3, 0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3, 0, 0, 0, 9, 3, 3, 0, 0, 0, 0, 0, 4, 1, 3, 3, 0, 0, 0, 3, 3}, 
            {0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 3, 0, 0, 3, 0, 0, 0, 6, 0, 3},
            {0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 3, 3, 3, 8, 3, 3, 3, 0, 0, 0, 1, 0, 0, 0}, 
            {0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0, 0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0, 0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0, 0, 1, 5, 5, 5, 5, 0, 3, 3, 0, 0, 3, 3, 0, 0, 0, 0, 2, 6, 0}, 
            {0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 5, 0, 0, 0, 3, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 
            {0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7, 0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7, 0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7, 0, 8, 6, 0, 0, 0, 1, 0, 0, 3, 3, 3, 0, 2, 0, 0, 0, 7, 7, 7}, 
            {0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0, 0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0, 0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0, 0, 0, 3, 3, 0, 0, 7, 6, 3, 3, 0, 0, 0, 1, 0, 0, 7, 7, 7, 0},
            {0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11, 0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11, 0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11, 0, 3, 3, 3, 0, 0, 2, 0, 0, 0, 0, 0, 1, 2, 0, 0, 7, 0, 0, 11}, 
            {0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0, 0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0, 0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0, 0, 0, 0, 0, 3, 2, 1, 6, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 10, 0}, 
            {0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0,  0, 0, 0, 2, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10}
            }; // 1

    private int m_level_3_map[][] = { 
    		{0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 6, 1, 0, 0, 9, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 1, 0, 0, 9, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 1, 0, 0, 9, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 1, 0, 0, 9, 1, 0, 0, 0, 2, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0},
            {0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 11, 0, 0, 0, 0}, 
            {0, 1, 0, 0, 0, 1, 2, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 2, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 2, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 2, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0}, 
            {0, 0, 7, 0, 0, 6, 7, 10, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 6, 7, 10, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 6, 7, 10, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 6, 7, 10, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0}, 
            {0, 1, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 6, 0, 0, 0, 1, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 6, 0, 0, 0, 1, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 6, 0, 0, 0, 1, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 6, 0, 0}, 
            {11, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 11, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 11, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 11, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 9, 6, 0, 0, 7, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 6, 0, 0, 7, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 6, 0, 0, 7, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 6, 0, 0, 7, 0, 0, 0, 0, 1, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 7, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 7, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 7, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 7, 0, 0, 0, 0, 9, 0, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 2, 0, 0}, 
            {0, 0, 3, 3, 3, 10, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 3, 3, 10, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 3, 3, 10, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 3, 3, 10, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 7, 0, 0}, 
            {0, 0, 1, 6, 3, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 1, 6, 3, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 1, 6, 3, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 1, 6, 3, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0}, 
            {0, 0, 3, 5, 3, 0, 1, 3, 1, 0, 0, 0, 9, 0, 0, 0, 4, 0, 0, 0, 0, 0, 3, 5, 3, 0, 1, 3, 1, 0, 0, 0, 9, 0, 0, 0, 4, 0, 0, 0, 0, 0, 3, 5, 3, 0, 1, 3, 1, 0, 0, 0, 9, 0, 0, 0, 4, 0, 0, 0, 0, 0, 3, 5, 3, 0, 1, 3, 1, 0, 0, 0, 9, 0, 0, 0, 4, 0, 0, 0}, 
            {0, 0, 3, 3, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 3, 3, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 3, 3, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 3, 3, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 11, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 11, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 11, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 11, 0, 0, 6, 0, 0, 0},
            {0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 6, 1, 0, 0, 9, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 1, 0, 0, 9, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 1, 0, 0, 9, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 1, 0, 0, 9, 1, 0, 0, 0, 2, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0},
            {0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 11, 0, 0, 0, 0}, 
            {0, 1, 0, 0, 0, 1, 2, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 2, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 2, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 2, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0}, 
            {0, 0, 7, 0, 0, 6, 7, 10, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 6, 7, 10, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 6, 7, 10, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 6, 7, 10, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0}, 
            {0, 1, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 6, 0, 0, 0, 1, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 6, 0, 0, 0, 1, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 6, 0, 0, 0, 1, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 6, 0, 0}, 
            {11, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 11, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 11, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 11, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 9, 6, 0, 0, 7, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 6, 0, 0, 7, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 6, 0, 0, 7, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 6, 0, 0, 7, 0, 0, 0, 0, 1, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 7, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 7, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 7, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 7, 0, 0, 0, 0, 9, 0, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 2, 0, 0}, 
            {0, 0, 3, 3, 3, 10, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 3, 3, 10, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 3, 3, 10, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 3, 3, 10, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 7, 0, 0}, 
            {0, 0, 1, 6, 3, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 1, 6, 3, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 1, 6, 3, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 1, 6, 3, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0}, 
            {0, 0, 3, 5, 3, 0, 1, 3, 1, 0, 0, 0, 9, 0, 0, 0, 4, 0, 0, 0, 0, 0, 3, 5, 3, 0, 1, 3, 1, 0, 0, 0, 9, 0, 0, 0, 4, 0, 0, 0, 0, 0, 3, 5, 3, 0, 1, 3, 1, 0, 0, 0, 9, 0, 0, 0, 4, 0, 0, 0, 0, 0, 3, 5, 3, 0, 1, 3, 1, 0, 0, 0, 9, 0, 0, 0, 4, 0, 0, 0}, 
            {0, 0, 3, 3, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 3, 3, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 3, 3, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 3, 3, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 11, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 11, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 11, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 11, 0, 0, 6, 0, 0, 0},
            {0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 6, 1, 0, 0, 9, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 1, 0, 0, 9, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 1, 0, 0, 9, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 1, 0, 0, 9, 1, 0, 0, 0, 2, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0},
            {0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 11, 0, 0, 0, 0}, 
            {0, 1, 0, 0, 0, 1, 2, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 2, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 2, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 2, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0}, 
            {0, 0, 7, 0, 0, 6, 7, 10, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 6, 7, 10, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 6, 7, 10, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 6, 7, 10, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0}, 
            {0, 1, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 6, 0, 0, 0, 1, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 6, 0, 0, 0, 1, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 6, 0, 0, 0, 1, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 6, 0, 0}, 
            {11, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 11, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 11, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 11, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 9, 6, 0, 0, 7, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 6, 0, 0, 7, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 6, 0, 0, 7, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 6, 0, 0, 7, 0, 0, 0, 0, 1, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 7, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 7, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 7, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 7, 0, 0, 0, 0, 9, 0, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 2, 0, 0}, 
            {0, 0, 3, 3, 3, 10, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 3, 3, 10, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 3, 3, 10, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 3, 3, 10, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 7, 0, 0}, 
            {0, 0, 1, 6, 3, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 1, 6, 3, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 1, 6, 3, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 1, 6, 3, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0}, 
            {0, 0, 3, 5, 3, 0, 1, 3, 1, 0, 0, 0, 9, 0, 0, 0, 4, 0, 0, 0, 0, 0, 3, 5, 3, 0, 1, 3, 1, 0, 0, 0, 9, 0, 0, 0, 4, 0, 0, 0, 0, 0, 3, 5, 3, 0, 1, 3, 1, 0, 0, 0, 9, 0, 0, 0, 4, 0, 0, 0, 0, 0, 3, 5, 3, 0, 1, 3, 1, 0, 0, 0, 9, 0, 0, 0, 4, 0, 0, 0}, 
            {0, 0, 3, 3, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 3, 3, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 3, 3, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 3, 3, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 11, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 11, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 11, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 11, 0, 0, 6, 0, 0, 0},
            {0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 6, 1, 0, 0, 9, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 1, 0, 0, 9, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 1, 0, 0, 9, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 1, 0, 0, 9, 1, 0, 0, 0, 2, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0},
            {0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 11, 0, 0, 0, 0}, 
            {0, 1, 0, 0, 0, 1, 2, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 2, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 2, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 2, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0}, 
            {0, 0, 7, 0, 0, 6, 7, 10, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 6, 7, 10, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 6, 7, 10, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 6, 7, 10, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0}, 
            {0, 1, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 6, 0, 0, 0, 1, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 6, 0, 0, 0, 1, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 6, 0, 0, 0, 1, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 6, 0, 0}, 
            {11, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 11, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 11, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 11, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 9, 6, 0, 0, 7, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 6, 0, 0, 7, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 6, 0, 0, 7, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 6, 0, 0, 7, 0, 0, 0, 0, 1, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 7, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 7, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 7, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 7, 0, 0, 0, 0, 9, 0, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 2, 0, 0}, 
            {0, 0, 3, 3, 3, 10, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 3, 3, 10, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 3, 3, 10, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 3, 3, 10, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 7, 0, 0}, 
            {0, 0, 1, 6, 3, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 1, 6, 3, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 1, 6, 3, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 1, 6, 3, 1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0}, 
            {0, 0, 3, 5, 3, 0, 1, 3, 1, 0, 0, 0, 9, 0, 0, 0, 4, 0, 0, 0, 0, 0, 3, 5, 3, 0, 1, 3, 1, 0, 0, 0, 9, 0, 0, 0, 4, 0, 0, 0, 0, 0, 3, 5, 3, 0, 1, 3, 1, 0, 0, 0, 9, 0, 0, 0, 4, 0, 0, 0, 0, 0, 3, 5, 3, 0, 1, 3, 1, 0, 0, 0, 9, 0, 0, 0, 4, 0, 0, 0}, 
            {0, 0, 3, 3, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 3, 3, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 3, 3, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 3, 3, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0}, 
            {0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 11, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 11, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 11, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 11, 0, 0, 6, 0, 0, 0}
    }; //

    private int m_level_4_map[][] = { 
    		{0, 0, 8, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 
    		{0, 0, 0, 0, 4, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 1, 7, 9, 0, 0, 0, 0, 0, 0, 1, 3, 7, 0, 0, 0, 0, 0, 0, 0, 0, 1, 7, 9, 0, 0, 0, 0, 0, 0, 1, 3, 7, 0, 0, 0, 0, 0, 0, 0, 0, 1, 7, 9, 0, 0, 0, 0, 0, 0, 1, 3, 7, 0, 0, 0, 0, 0, 0, 0, 0, 1, 7, 9, 0, 0, 0, 0, 0, 0, 1, 3, 7, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 10, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0}, 
    		{8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 6, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 1, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 2, 4, 0, 0, 0, 0, 0, 0, 5, 6, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 0, 0, 0, 0, 0, 0, 5, 6, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 0, 0, 0, 0, 0, 0, 5, 6, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 0, 0, 0, 0, 0, 0, 5, 6, 2, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0},  
    		{0, 0, 0, 0, 1, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 6, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    		{0, 0, 8, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 
    		{0, 0, 0, 0, 4, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 1, 7, 9, 0, 0, 0, 0, 0, 0, 1, 3, 7, 0, 0, 0, 0, 0, 0, 0, 0, 1, 7, 9, 0, 0, 0, 0, 0, 0, 1, 3, 7, 0, 0, 0, 0, 0, 0, 0, 0, 1, 7, 9, 0, 0, 0, 0, 0, 0, 1, 3, 7, 0, 0, 0, 0, 0, 0, 0, 0, 1, 7, 9, 0, 0, 0, 0, 0, 0, 1, 3, 7, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 10, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0}, 
    		{8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 6, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 1, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 2, 4, 0, 0, 0, 0, 0, 0, 5, 6, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 0, 0, 0, 0, 0, 0, 5, 6, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 0, 0, 0, 0, 0, 0, 5, 6, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 0, 0, 0, 0, 0, 0, 5, 6, 2, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0},  
    		{0, 0, 0, 0, 1, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 6, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    		{0, 0, 8, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 
    		{0, 0, 0, 0, 4, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 1, 7, 9, 0, 0, 0, 0, 0, 0, 1, 3, 7, 0, 0, 0, 0, 0, 0, 0, 0, 1, 7, 9, 0, 0, 0, 0, 0, 0, 1, 3, 7, 0, 0, 0, 0, 0, 0, 0, 0, 1, 7, 9, 0, 0, 0, 0, 0, 0, 1, 3, 7, 0, 0, 0, 0, 0, 0, 0, 0, 1, 7, 9, 0, 0, 0, 0, 0, 0, 1, 3, 7, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 10, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0}, 
    		{8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 6, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 1, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 2, 4, 0, 0, 0, 0, 0, 0, 5, 6, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 0, 0, 0, 0, 0, 0, 5, 6, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 0, 0, 0, 0, 0, 0, 5, 6, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 0, 0, 0, 0, 0, 0, 5, 6, 2, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0},  
    		{0, 0, 0, 0, 1, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 6, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    		{0, 0, 8, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 
    		{0, 0, 0, 0, 4, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 1, 7, 9, 0, 0, 0, 0, 0, 0, 1, 3, 7, 0, 0, 0, 0, 0, 0, 0, 0, 1, 7, 9, 0, 0, 0, 0, 0, 0, 1, 3, 7, 0, 0, 0, 0, 0, 0, 0, 0, 1, 7, 9, 0, 0, 0, 0, 0, 0, 1, 3, 7, 0, 0, 0, 0, 0, 0, 0, 0, 1, 7, 9, 0, 0, 0, 0, 0, 0, 1, 3, 7, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 10, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0}, 
    		{8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 6, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 1, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 2, 4, 0, 0, 0, 0, 0, 0, 5, 6, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 0, 0, 0, 0, 0, 0, 5, 6, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 0, 0, 0, 0, 0, 0, 5, 6, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 0, 0, 0, 0, 0, 0, 5, 6, 2, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 8, 0},  
    		{0, 0, 0, 0, 1, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 6, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}
    };


    private int m_level_5_map[][] = { 
    		{0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0}, 
    		{2, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 0, 0, 0, 2, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 0, 0, 0, 2, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 0, 0, 0, 2, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 0, 0, 0}, 
    		{7, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 2, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 2, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 2, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 2, 0, 0, 3, 3, 3, 3, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0},
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 7, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0},
    		{0, 0, 0, 0, 3, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 3, 3, 0, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 3, 3, 3, 3, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    		{0, 0, 0, 3, 3, 0, 0, 0, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 3, 3, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0}, 
    		{2, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 0, 0, 0, 2, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 0, 0, 0, 2, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 0, 0, 0, 2, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 0, 0, 0}, 
    		{7, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 2, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 2, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 2, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 2, 0, 0, 3, 3, 3, 3, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0},
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 7, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0},
    		{0, 0, 0, 0, 3, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 3, 3, 0, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8}, 
    		{0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 3, 3, 3, 3, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    		{0, 0, 0, 3, 3, 0, 0, 0, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 3, 3, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8}, 
    		{0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    		{0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0}, 
    		{2, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 0, 0, 0, 2, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 0, 0, 0, 2, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 0, 0, 0, 2, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 0, 0, 8}, 
    		{7, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 2, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 2, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 2, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 2, 0, 0, 3, 3, 3, 3, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 0, 0, 0, 0, 8},
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 7, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 8},
    		{0, 0, 0, 0, 3, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 3, 3, 0, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8}, 
    		{0, 0, 0, 3, 3, 3, 3, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    		{0, 0, 0, 3, 3, 0, 0, 0, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 3, 3, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8}, 
    		{0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    		{0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0}, 
    		{2, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 0, 0, 0, 2, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 0, 0, 0, 2, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 0, 0, 0, 2, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 0, 0, 0}, 
    		{7, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 7, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 2, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 2, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 2, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 2, 0, 0, 3, 3, 3, 3, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0},
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 8}, 
    		{0, 0, 0, 0, 0, 0, 7, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 8}, 
    		{0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 8},
    		{0, 0, 0, 0, 3, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 3, 3, 0, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 3, 3, 3, 3, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 3, 3, 0, 2, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    		{0, 0, 0, 3, 3, 0, 0, 0, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 2, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 3, 3, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 
    		{0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    		
    }; // 2

    /** level speeds **/
    public final static int LEVEL_SPEED = 2000;

    public static final int BUNNY_START_X = 0;
    public static final int BUNNY_START_Y = 0;

    /** The different possible states. **/
    public final static int STATE_START_LEVEL = 1;
    public final static int STATE_GAME = 2;
    public final static int STATE_BUNNY_DYING = 3;
    public final static int STATE_GAME_OVER = 4;
    public final static int STATE_GAME_DONE = 5;

    private DrawThread drawThread;
    
    /**
     *
     * @param can GameCanvas
     * @param screenWidth int
     * @param screenHeight int
     */
    public EasterHuntGameEngine( Context context  ) {
    	super(context);
    	EasterHuntGameEngine.m_context = context;
        m_score = new EasterHuntScore();
        this.m_level = 1;
    }
    

    public EasterHuntGameEngine(Context context, AttributeSet attrs) {
        super(context, attrs);
    	EasterHuntGameEngine.m_context = context;
        m_score = new EasterHuntScore();
        this.m_level = 1;
    }

    public EasterHuntGameEngine(Context context, AttributeSet attrs, int defStyle) {
        super(context, attrs, defStyle);
    	EasterHuntGameEngine.m_context = context;
        m_score = new EasterHuntScore();
        this.m_level = 1;
    }

    public void initialize() {
        getHolder().addCallback(this);
        setFocusable(true);
        try{
        	this.m_volume = ImageUtils.loadImage( R.drawable.volume, m_context );
        	this.m_muted = ImageUtils.loadImage( R.drawable.mute, m_context );
        }catch(Exception e){
        	Log.e(TAG, "Could not load volume images: "+e.toString(), e);
        }
        this.loadLevel();
    }

    public void startThread() {
    	if( drawThread == null ){
    		drawThread = new DrawThread(getHolder(), this);
    		drawThread.setRunning(true);
    		drawThread.start();
    	}
    }

    public void stopThread() {
    	if( drawThread != null ){    		
    		drawThread.setRunning(false); 
    		drawThread = null;
    	}
    }

	public static String getText(int index){
		return m_context.getResources().getText(index).toString();
	}
    
    /**
     * Loads the corresponding level...
     *
     * @param level int
     */
    
	protected final void loadLevel( ) {
		// Get screen size for each loading of a new level...
        WindowManager wm = (WindowManager) EasterHuntActivity.getInstance().getSystemService(Context.WINDOW_SERVICE);               
        this.m_maxScreenSize.set( wm.getDefaultDisplay().getWidth(), wm.getDefaultDisplay().getHeight() );
        
        // The current map
        switch ( this.m_level ) {
            case 1:
                this.m_currentMap =
                        new EasterHuntMap( 	this.m_maxScreenSize.x,
                        					this.m_maxScreenSize.y,
                        					this.m_level_1_map );
                this.m_currentMap.loadMap();
                this.m_currentMap.loadMapTiles();
                this.m_numberOfEggs = 10;
                this.m_numberOfEnemies = 8;
                m_score.newLevel();
                break;
            case 2:
                this.m_currentMap =
                        new EasterHuntMap( this.m_maxScreenSize.x,
                        		this.m_maxScreenSize.y,
                                           this.m_level_2_map );
                this.m_currentMap.loadMap();
                this.m_currentMap.loadMapTiles();
                this.m_numberOfEggs = 10;
                this.m_numberOfEnemies = 9;
                m_score.newLevel();
                break;
            case 3:
                this.m_currentMap =
                        new EasterHuntMap( 	this.m_maxScreenSize.x,
                        		this.m_maxScreenSize.y,
            								this.m_level_3_map );
                this.m_currentMap.loadMap();
                this.m_currentMap.loadMapTiles();
                this.m_numberOfEggs = 10;
                this.m_numberOfEnemies = 10;
                m_score.newLevel();
                break;
            case 4:
                this.m_currentMap =
                        new EasterHuntMap( 	this.m_maxScreenSize.x,
                        		this.m_maxScreenSize.y,
            								this.m_level_4_map );
                this.m_currentMap.loadMap();
                this.m_currentMap.loadMapTiles();
                this.m_numberOfEggs = 10;
                this.m_numberOfEnemies = 10;
                m_score.newLevel();
                break;
            case 5:
                this.m_currentMap =
                        new EasterHuntMap( 	this.m_maxScreenSize.x,
                        		this.m_maxScreenSize.y,
            								this.m_level_5_map );
                this.m_currentMap.loadMap();
                this.m_currentMap.loadMapTiles();
                this.m_numberOfEggs = 10;
                this.m_numberOfEnemies = 15;
                m_score.newLevel();
                break;
                // Game is finished! Now we should shift
                // to the main menu!
            case 6:
                this.m_state = STATE_GAME_DONE;
                return;
        }

        // Create player
        this.m_bunny = new EasterHuntBunny( this.m_currentMap,
                                            this,
                                            BUNNY_START_X,
                                            BUNNY_START_Y );

        // Create enemies...
        this.m_emenies = new EasterHuntFox[this.m_numberOfEnemies];
        for ( int i = 0; this.m_numberOfEnemies > i; i++ ) {
            // X Should not be outside the limits...
            int y = EasterHuntGameEngine.rand( this.m_currentMap.m_map.length );
            while ( y > this.m_currentMap.m_map.length ) {
                y = y / 2;
            }
            // Y is allays some where close to the left side of the board...
            int x = this.m_currentMap.m_map[0].length -1;
            this.m_emenies[i] =
                    new EasterHuntFox( this.m_currentMap,
                                       this,
                                       x,
                                       y );
            // increase the enemy movment speed pending level!
            EasterHuntFox.MOVMENT_TIME_WAIT = LEVEL_SPEED / this.m_level;
        }

        // Inform about the new level...
        this.m_message = EasterHuntGameEngine.getText( R.string.level ) + this.m_level ;
        SoundEngine.getInstance().playSound(SoundEngine.NEXT_LEVEL_SOUND, SoundEngine.HIGH_PRIORITY, EasterHuntGameEngine.m_context );
        
        // Empty key events as well!
        this.m_keyPress = 0;
    }

    /**
     * The current score of the player, note that we would now like
     * to check how many eggs there are left!
     */
    private final void updateScore(  ) {
        m_score.eggTaken();
        this.m_numberOfEggs--;
        // Now we would like to increase the level!
        if ( this.m_numberOfEggs == 0 ) {
            this.m_level += 1;
            this.loadLevel(  );        
        } else {
            this.m_eggMessage = this.m_numberOfEggs + " " + EasterHuntGameEngine.getText( R.string.eggs );
        }
    }

    /**
     * Moves the enemies according to how many are active,
     * look at the EasterHuntFox for more details on the movment
     * patterns.
     *
     */
    private final void moveEnemies() {

        // Create enemies if they have died...
        for ( int i = 0; this.m_numberOfEnemies > i; i++ ) {
            if ( this.m_emenies[i] == null ) {
                // X is always some where close to the left side of the board...
                int x = this.m_currentMap.m_tile_max_x;
                // Y Should not be outside the limits...
                int y = EasterHuntGameEngine.rand( 2 );
                if ( y > this.m_currentMap.m_tile_max_y ) {
                    y = this.m_currentMap.m_tile_max_y;
                }
                this.m_emenies[i] =
                        new EasterHuntFox( this.m_currentMap,
                                           this,
                                           x,
                                           y );
            }
        }

        // Move the enemies...
        for ( int i = 0; this.m_numberOfEnemies > i; i++ ) {
            this.m_emenies[i].updateAI( this.m_bunny,
                                        this.m_currentMap );
        }
    }

    public static final int LOCATION_OF_DEFAULT = 0;
    public static final int LOCATION_OF_DESTROYING_BUSH_1_SEQUENCE = 2;
    public static final int START_OF_DESTROYING_BUSH_1_SEQUENCE = 12;
    public static final int STOP_OF_DESTROYING_BUSH_1_SEQUENCE = 16;
    public static final int LOCATION_OF_DESTROYING_BUSH_2_SEQUENCE = 7;
    public static final int START_OF_DESTROYING_BUSH_2_SEQUENCE = 17;
    public static final int STOP_OF_DESTROYING_BUSH_2_SEQUENCE = 20;
    public static final int EGG_TYPE_1 = 8;
    public static final int EGG_TYPE_2 = 9;
    public static final int EGG_TYPE_3 = 10;
    public static final int EGG_TYPE_4 = 11;

    /**
     * Checks if the position can be moved to or not and returns a
     * boolean.
     *
     * @param x int tile x
     * @param y int tile y
     * @return boolean
     */
    public final boolean canMove( int x, int y, boolean bunny ) {
    	
    	try{
	        // First check boundaries, no minus or stuff.
	        if ( x < 0 || y < 0 ) {
	            return false;
	        }
	        if ( x >= this.m_currentMap.m_map[0].length ||
	             y >= this.m_currentMap.m_map.length ) {
	            return false;
	        }
	        boolean b = this.specialEffects( x, y, bunny );
	        if ( !b ) {
	            return b;
	        }
	
	        // Check if we are doing the fox and if the fox will kill
	        // the rabbit?
	        if ( !bunny ) {
	            if ( this.m_bunny.m_tileLocationX == x &&
	                 this.m_bunny.m_tileLocationY == y ) {
	            	SoundEngine.getInstance().playSound(SoundEngine.DIE_SOUND,
	                        SoundEngine.HIGH_PRIORITY, EasterHuntActivity.getInstance().getApplicationContext());
	                this.m_bunny.m_facingDircetion = EasterHuntBunny.DYING;
	                // We are not interested in input or fox movement now!
	                this.setState( STATE_BUNNY_DYING );
	                return false;
	            }
	        }
	
	        // Now check objects...
	        if ( this.m_currentMap.m_map[y][x] == 1 ) {
	            return false;
	        }
	        if ( this.m_currentMap.m_map[y][x] == 4 ) {
	            return false;
	        }        
	        if ( this.m_currentMap.m_map[y][x] == 6 ) {
	            return false;
	        }
    	}catch(Exception e){
    		Log.i(TAG, "Exception in canMove:"+e.toString(), e);
    	}
        return true;
    }


    /**
     * Checks if the position can be moved to or not and returns a
     * boolean.
     *
     * @param x int
     * @param y int
     * @return boolean
     */
    private final boolean specialEffects( int x, int y, boolean pickupEggs ) {

        if ( this.m_currentMap.m_map[y][x] ==
             LOCATION_OF_DESTROYING_BUSH_1_SEQUENCE ) {
            this.m_currentMap.m_map[y][x] = START_OF_DESTROYING_BUSH_1_SEQUENCE;
            return false;
        }
        if ( this.m_currentMap.m_map[y][x] >=
             START_OF_DESTROYING_BUSH_1_SEQUENCE &&
             this.m_currentMap.m_map[y][x] <=
             STOP_OF_DESTROYING_BUSH_1_SEQUENCE ) {
            this.m_currentMap.m_map[y][x]++;
            if ( this.m_currentMap.m_map[y][x] ==
                 STOP_OF_DESTROYING_BUSH_1_SEQUENCE ) {
                this.m_currentMap.m_map[y][x] = LOCATION_OF_DEFAULT;
                return true;
            }
            return false;
        }
        // The tree like bush
        if ( this.m_currentMap.m_map[y][x] ==
             LOCATION_OF_DESTROYING_BUSH_2_SEQUENCE ) {
            this.m_currentMap.m_map[y][x] = START_OF_DESTROYING_BUSH_2_SEQUENCE;
            return false;
        }
        if ( this.m_currentMap.m_map[y][x] >=
             START_OF_DESTROYING_BUSH_2_SEQUENCE &&
             this.m_currentMap.m_map[y][x] <=
             STOP_OF_DESTROYING_BUSH_2_SEQUENCE ) {
            this.m_currentMap.m_map[y][x]++;
            if ( this.m_currentMap.m_map[y][x] ==
                 STOP_OF_DESTROYING_BUSH_2_SEQUENCE ) {
                this.m_currentMap.m_map[y][x] = LOCATION_OF_DEFAULT;
                return true;
            }
            return false;
        } // for x

        // Foxes can not pickup objects!
        if ( !pickupEggs ) {
            return true;
        }
        
        // Do the eggs
        if ( this.m_currentMap.m_map[y][x] == EGG_TYPE_1 ) {
            this.m_currentMap.m_map[y][x] = LOCATION_OF_DEFAULT;
            this.updateScore( );
            SoundEngine.getInstance().playSound(SoundEngine.EGG_PICK_UP_SOUND, SoundEngine.HIGH_PRIORITY, EasterHuntGameEngine.m_context );
        }
        // Do the eggs
        if ( this.m_currentMap.m_map[y][x] == EGG_TYPE_2 ) {
            this.m_currentMap.m_map[y][x] = LOCATION_OF_DEFAULT;
            this.updateScore( );
            SoundEngine.getInstance().playSound(SoundEngine.EGG_PICK_UP_SOUND, SoundEngine.HIGH_PRIORITY, EasterHuntGameEngine.m_context );
        }
        // Do the eggs
        if ( this.m_currentMap.m_map[y][x] == EGG_TYPE_3 ) {
            this.m_currentMap.m_map[y][x] = LOCATION_OF_DEFAULT;
            this.updateScore( );
            SoundEngine.getInstance().playSound(SoundEngine.EGG_PICK_UP_SOUND, SoundEngine.HIGH_PRIORITY, EasterHuntGameEngine.m_context );
        }
        // Do the eggs
        if ( this.m_currentMap.m_map[y][x] == EGG_TYPE_4 ) {
            this.m_currentMap.m_map[y][x] = LOCATION_OF_DEFAULT;
            this.updateScore( );
            SoundEngine.getInstance().playSound(SoundEngine.EGG_PICK_UP_SOUND, SoundEngine.HIGH_PRIORITY, EasterHuntGameEngine.m_context );
        }
        
        return true;
    }

    /**
     *
     * @param g Graphics
     */
    public final void onDraw( Canvas canvas ) {
    	try{
    		if( canvas != null ){
    			// Draw white..
    			canvas.drawColor(Color.WHITE); 
		        // Draw map..
		        this.m_currentMap.drawMap( canvas, this.m_bunny.m_tileLocationX,
		        							this.m_bunny.m_tileLocationY );
		        // Draw bunny...
		        this.m_bunny.render( canvas );
		
		        // Draw enemies...
		        for ( int i = 0; this.m_numberOfEnemies > i; i++ ) {
		            this.m_emenies[i].render( this.m_bunny,
		                                      canvas );
		        }
		        // Check if we are paused or not, this makes sure
		        // that we are not showing more then one message at the same time
		        // and the priority is paused, message, and eggs left.
		        //OBS
	//	        if ( this.getPaused() ) {
	//	        	Paint mPaint = getTextPaint();
	//	        	PointF p = getTextCenterToDraw(EasterHuntGameEngine.getText(R.string.paused), mPaint);
	//	        	canvas.drawText(EasterHuntGameEngine.getText(R.string.paused), p.x, p.y, mPaint);        	
	//	        } else 
		        	if ( this.m_message != null ) {
		        	Paint mPaint = getTextPaint();
		        	PointF p = getTextCenterToDraw(this.m_message, mPaint);
		        	canvas.drawText(this.m_message, p.x, p.y, mPaint);            
		        } else if ( this.m_eggMessage != null ) {
		        	Paint mPaint = getTextPaint();
		        	PointF p = getTextCenterToDraw(this.m_eggMessage, mPaint);
		        	canvas.drawText(this.m_eggMessage, p.x, p.y, mPaint);              
		        }
		        
		        // Draw Volume
		        if( this.m_volume != null && this.m_muted != null ){		        	
		        	if( SoundEngine.getInstance().isMuted() ){		        		
		        		canvas.drawBitmap(this.m_muted, (this.m_maxScreenSize.x-80), 0+10, null );
		        	}else{
		        		canvas.drawBitmap(this.m_volume, (this.m_maxScreenSize.x-80), 0+10, null );
		        	}
		        }
		        
		        // Draw Score
		        m_score.draw(canvas);
    		}
    	}catch(Exception e){
    		Log.e(TAG, "Exception while drawing:"+e.toString(), e);
    	}
    

    }
    
    private static final int TEXT_SIZE = 34;
    
    private static Paint getTextPaint(){
    	Paint mPaint = new Paint();
        mPaint.setStyle(Style.FILL);
        mPaint.setTextSize(TEXT_SIZE);
        mPaint.setColor(Color.BLACK);
        mPaint.setTextAlign(Align.CENTER);
        mPaint.setTypeface(Typeface.DEFAULT_BOLD);
        return mPaint;
    }
    
    private static PointF getTextCenterToDraw(String text,  Paint paint) {
        Rect textBounds = new Rect();
        WindowManager wm = (WindowManager) EasterHuntActivity.getInstance().getSystemService(Context.WINDOW_SERVICE);        
        RectF region = new RectF(0, 0, wm.getDefaultDisplay().getWidth(), wm.getDefaultDisplay().getHeight() );
        paint.getTextBounds(text, 0, text.length(), textBounds);
        float x = region.centerX() - textBounds.width() * 0.3f;
        float y = region.centerY() + textBounds.height() * 0.4f;
        return new PointF(x, y);
    }

    /**
     * Provides the random number for what direction
     * this object is supposed to be going in.
     *
     * @param scale int The scale of the return value,
     * @return int The random number.
     */
    public final static int rand( int scale ) {
        return ( randomObj.nextInt() << 1 >>> 1 ) % scale;
    }

    public static final int UP = 2;
    public static final int DOWN = 3;
    public static final int LEFT = 4;
    public static final int RIGHT = 5;
        
    @Override
    public boolean onTouchEvent(MotionEvent event) {
    	this.keyPressed((int)event.getX(), (int)event.getY());
    	return true;
    }
    
    /**
     * translate the x y coordinates into what we know..
     */    
    protected void keyPressed( int x, int y ){
    	int centerX = this.m_maxScreenSize.x / 2;
    	int centerY = this.m_maxScreenSize.y / 2;
    	int width = this.m_maxScreenSize.x/4;

    	if( x > centerX && (y < (centerY+width) && y > (centerY-width)) ){
    		this.keyPressed(RIGHT);
    	}
		if( x < centerX && (y < (centerY+width) && y > (centerY-width))){
			this.keyPressed(LEFT);
		}
		if( y > centerY && (x < (centerX+width) && x > (centerX-width))){
			this.keyPressed(DOWN);			
		}
		if( y < centerY && (x < (centerX+width) && x > (centerX-width))){
			this.keyPressed(UP);
		}
		// Check if its on the volume button
		if( y < 70 && x > ((this.m_maxScreenSize.x-90)) ){
			SoundEngine.getInstance().setMute( !SoundEngine.getInstance().isMuted() );
		}
    	this.m_message = null;
    	this.m_eggMessage = null;
    }
    
    /**
     * Called when the user presses a key
     */
    protected void keyPressed( int keyCode ) {
        
        // Take ceare of the key event that the user asked us to handle
        switch ( keyCode ) {

            case EasterHuntGameEngine.UP:
                this.m_keyPress = EasterHuntObject.DIRECTION_UP;
                break;

            case EasterHuntGameEngine.DOWN:
                this.m_keyPress = EasterHuntObject.DIRECTION_DOWN;
                break;

            case EasterHuntGameEngine.LEFT:
                this.m_keyPress = EasterHuntObject.DIRECTION_LEFT;
                break;

            case EasterHuntGameEngine.RIGHT:
                this.m_keyPress = EasterHuntObject.DIRECTION_RIGHT;
                break;
        }
        // Empty in-game messages and repaint!
    }

    /**
     * Sets the current state of the enine.
     * @param state int
     */
    public final void setState( int state ) {
        this.m_state = state;
    }

    /**
     * The animation and runtime event engine. Using states but at
     * this moment that is perhaps a little bit over the edge!
     */
    public final void update() {
    	
        switch ( this.m_state ) {

            case STATE_START_LEVEL:
                this.m_state = STATE_GAME;
                break;

                // Game state
            case STATE_GAME:
                // Move bunny..
                if ( this.m_keyPress != 0 ) {
                    this.m_bunny.move( this.m_keyPress );
                    this.m_keyPress = 0;
                }

                // Move enemies..
                if ( this.m_message == null ) {
                    this.moveEnemies();
                }
                // Update score
                m_score.updateScore();
                break;

                // Bunny is dying, update animation!
            case STATE_BUNNY_DYING:
                this.m_bunny.move( EasterHuntBunny.DYING );
                break;

                // Game Over, i.e. bunny died!
            case STATE_GAME_OVER:               

                // do next as well!
                // Finish the game!
            case STATE_GAME_DONE:
                // Wonder if the stop actually removes this current
                // thread!
            	this.stopThread();
            	EasterHuntActivity.getInstance().showGameOverScreen();
                return;
        }

    }

    /**
     * Loads everything
     */
    public final void load( ) {
        this.m_state = STATE_START_LEVEL;
        this.loadLevel();
    }

    @Override
    public void surfaceDestroyed(SurfaceHolder holder) {
        // TODO Auto-generated method stub
    }

    @Override
    public void surfaceChanged(SurfaceHolder holder, int format, int width,
            int height) {
        // TODO Auto-generated method stub
    }

    @Override
    public void surfaceCreated(SurfaceHolder holder) {
        // TODO Auto-generated method stub
    }

}
